@@ -318,6 +318,118 @@ async def handle_set_mode_request(mqtt: NavienMqttClient, device: Device, mode_n
         _logger.error(f"Error setting mode: {e}")
 
 
+async def handle_set_dhw_temp_request(mqtt: NavienMqttClient, device: Device, temperature: int):
+    """
+    Set DHW target temperature and display the response.
+
+    Args:
+        mqtt: MQTT client instance
+        device: Device to control
+        temperature: Target temperature in Fahrenheit (display value)
+    """
+    # Validate temperature range
+    # Based on MQTT client documentation: display range approximately 115-150°F
+    if temperature < 115 or temperature > 150:
+        _logger.error(f"Temperature {temperature}°F is out of range. Valid range: 115-150°F")
+        return
+
+    # Set up callback to capture status response after temperature change
+    future = asyncio.get_running_loop().create_future()
+    responses = []
+
+    def on_status_response(status):
+        if not future.done():
+            responses.append(status)
+            # Complete after receiving response
+            future.set_result(None)
+
+    # Subscribe to status updates to see the temperature change result
+    await mqtt.subscribe_device_status(device, on_status_response)
+
+    try:
+        _logger.info(f"Setting DHW target temperature to {temperature}°F...")
+
+        # Send the temperature change command using display temperature
+        await mqtt.set_dhw_temperature_display(device, temperature)
+
+        # Wait for status response (temperature change confirmation)
+        try:
+            await asyncio.wait_for(future, timeout=15)
+
+            if responses:
+                status = responses[0]
+                print(json.dumps(asdict(status), indent=2, default=_json_default_serializer))
+                _logger.info(
+                    f"Temperature change successful. New target: "
+                    f"{status.dhwTargetTemperatureSetting}°F"
+                )
+            else:
+                _logger.warning("Temperature command sent but no status response received")
+
+        except asyncio.TimeoutError:
+            _logger.error("Timed out waiting for temperature change confirmation")
+
+    except Exception as e:
+        _logger.error(f"Error setting temperature: {e}")
+
+
+async def handle_power_request(mqtt: NavienMqttClient, device: Device, power_on: bool):
+    """
+    Set device power state and display the response.
+
+    Args:
+        mqtt: MQTT client instance
+        device: Device to control
+        power_on: True to turn on, False to turn off
+    """
+    action = "on" if power_on else "off"
+    _logger.info(f"Turning device {action}...")
+
+    # Set up callback to capture status response after power change
+    future = asyncio.get_running_loop().create_future()
+
+    def on_power_change_response(status: DeviceStatus):
+        if not future.done():
+            future.set_result(status)
+
+    try:
+        # Subscribe to status updates
+        await mqtt.subscribe_device_status(device, on_power_change_response)
+
+        # Send power command
+        await mqtt.set_power(device, power_on)
+
+        # Wait for response with timeout
+        status = await asyncio.wait_for(future, timeout=10.0)
+
+        _logger.info(f"Device turned {action} successfully!")
+
+        # Display relevant status information
+        print(
+            json.dumps(
+                {
+                    "result": "success",
+                    "action": action,
+                    "status": {
+                        "operationMode": status.operationMode.name,
+                        "dhwOperationSetting": status.dhwOperationSetting.name,
+                        "dhwTemperature": f"{status.dhwTemperature}°F",
+                        "dhwChargePer": f"{status.dhwChargePer}%",
+                        "tankUpperTemperature": f"{status.tankUpperTemperature:.1f}°F",
+                        "tankLowerTemperature": f"{status.tankLowerTemperature:.1f}°F",
+                    },
+                },
+                indent=2,
+            )
+        )
+
+    except asyncio.TimeoutError:
+        _logger.error(f"Timed out waiting for power {action} confirmation")
+
+    except Exception as e:
+        _logger.error(f"Error turning device {action}: {e}")
+
+
 async def handle_monitoring(mqtt: NavienMqttClient, device: Device, output_file: str):
     """Start periodic monitoring and write status to CSV."""
     _logger.info(f"Starting periodic monitoring. Writing updates to {output_file}")
@@ -360,14 +472,41 @@ async def async_main(args: argparse.Namespace):
         await mqtt.connect()
         _logger.info("MQTT client connected.")
 
-        if args.status:
-            await handle_status_request(mqtt, device)
-        elif args.device_info:
+        if args.device_info:
             await handle_device_info_request(mqtt, device)
         elif args.device_feature:
             await handle_device_feature_request(mqtt, device)
+        elif args.power_on:
+            await handle_power_request(mqtt, device, power_on=True)
+            # If --status was also specified, get status after power change
+            if args.status:
+                _logger.info("Getting updated status after power on...")
+                await asyncio.sleep(2)  # Brief pause for device to process
+                await handle_status_request(mqtt, device)
+        elif args.power_off:
+            await handle_power_request(mqtt, device, power_on=False)
+            # If --status was also specified, get status after power change
+            if args.status:
+                _logger.info("Getting updated status after power off...")
+                await asyncio.sleep(2)  # Brief pause for device to process
+                await handle_status_request(mqtt, device)
         elif args.set_mode:
             await handle_set_mode_request(mqtt, device, args.set_mode)
+            # If --status was also specified, get status after setting mode
+            if args.status:
+                _logger.info("Getting updated status after mode change...")
+                await asyncio.sleep(2)  # Brief pause for device to process
+                await handle_status_request(mqtt, device)
+        elif args.set_dhw_temp:
+            await handle_set_dhw_temp_request(mqtt, device, args.set_dhw_temp)
+            # If --status was also specified, get status after setting temperature
+            if args.status:
+                _logger.info("Getting updated status after temperature change...")
+                await asyncio.sleep(2)  # Brief pause for device to process
+                await handle_status_request(mqtt, device)
+        elif args.status:
+            # Status-only request
+            await handle_status_request(mqtt, device)
         else:  # Default to monitor
             await handle_monitoring(mqtt, device, args.output)
 
@@ -404,13 +543,15 @@ def parse_args(args):
         help="Navien account password. Overrides NAVIEN_PASSWORD env var.",
     )
 
-    # Operation modes
-    group = parser.add_mutually_exclusive_group()
-    group.add_argument(
+    # Status check (can be combined with other actions)
+    parser.add_argument(
         "--status",
         action="store_true",
-        help="Fetch and print the current device status once, then exit.",
+        help="Fetch and print the current device status. Can be combined with control commands.",
     )
+
+    # Primary action modes (mutually exclusive)
+    group = parser.add_mutually_exclusive_group()
     group.add_argument(
         "--device-info",
         action="store_true",
@@ -428,6 +569,23 @@ def parse_args(args):
         help="Set operation mode and display response. "
         "Options: heat-pump, electric, energy-saver, high-demand, vacation, standby",
     )
+    group.add_argument(
+        "--set-dhw-temp",
+        type=int,
+        metavar="TEMP",
+        help="Set DHW (Domestic Hot Water) target temperature in Fahrenheit "
+        "(115-150°F) and display response.",
+    )
+    group.add_argument(
+        "--power-on",
+        action="store_true",
+        help="Turn the device on and display response.",
+    )
+    group.add_argument(
+        "--power-off",
+        action="store_true",
+        help="Turn the device off and display response.",
+    )
     group.add_argument(
         "--monitor",
         action="store_true",
